@@ -9,28 +9,22 @@ class view(object):
        under the 3D view. If you have a predefined cutom view, 
        you can use the predefined commands in icn3dpy.
     '''
-    def __init__(self,width=640,height=480,q="",para="",command="",full=1,v=""):
+    def __init__(self,width=640,height=480,q="",para="",command="",v=""):
         '''Create a iCn3D view.
             width -- width of 3D canvas in pixels
             height -- height of 3D canvas in pixels
             q -- query, e.g., q='mmdbid=1kq2'
             para -- iCn3D parameters (e.g., para='showanno=1&show2d=1') defined at www.ncbi.nlm.nih.gov/Structure/icn3d/icn3d.html#parameters
             command -- iCn3D commands (e.g., command='color spectrum') defined at www.ncbi.nlm.nih.gov/Structure/icn3d/icn3d.html#commands
-            full -- 1: full version using icn3d_all_full.min.js, 0: simple version using icn3d_all_simple.min.js
             v -- version of iCn3D, e.g., v='2.18.0'
         '''
         if v != '':
             v = '_' + v
         
-        if full == 1:
-            jsfile = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/es5/icn3d_all_full' + v + '.min.js'
-            css1file = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/lib/jquery-ui' + v + '.min.css'
-            css2file = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/icn3d_full_ui' + v + '.css'
-        else:
-            jsfile = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/es5/icn3d_all_simple' + v + '.min.js'
-            css1file = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/lib/jquery-ui' + v + '.min.css'
-            css2file = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/icn3d_simple_ui' + v + '.css'
-        
+        jsfile = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/es5/icn3d_all_full' + v + '.min.js'
+        css1file = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/lib/jquery-ui' + v + '.min.css'
+        css2file = 'https://www.ncbi.nlm.nih.gov/Structure/icn3d/icn3d' + v + '.css'
+
         divid = "icn3dviewerUNIQUEID"
         warnid = "icn3dwarningUNIQUEID"
         self.uniqueid = None
@@ -104,7 +98,7 @@ css1
 
         self.startjs += 'cfg = {divid: "%s", %swidth: "%spx", height: "%spx", mobilemenu: 1, notebook: 1, command: \'%s\', %s};\n' % (divid, inputid, width, height, command, para)
 
-        self.startjs += 'viewerUNIQUEID = new iCn3DUI(cfg);\n'
+        self.startjs += 'viewerUNIQUEID = new icn3d.iCn3DUI(cfg);\n'
         
         self.endjs = "viewerUNIQUEID.show3DStructure();\n" + self.endjs;
         
